# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_rate_limiter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_rate_limiter.proto',
  package='Ydb.RateLimiter',
  syntax='proto3',
  serialized_options=b'\n\025tech.ydb.rate_limiterB\021RateLimiterProtosP\001Z>github.com/ydb-platform/ydb-go-genproto/protos/Ydb_RateLimiter\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dprotos/ydb_rate_limiter.proto\x12\x0fYdb.RateLimiter\x1a\x1aprotos/ydb_operation.proto\"\x95\x01\n\x17HierarchicalDrrSettings\x12\x1c\n\x14max_units_per_second\x18\x01 \x01(\x01\x12\"\n\x1amax_burst_size_coefficient\x18\x02 \x01(\x01\x12\x1c\n\x14prefetch_coefficient\x18\x03 \x01(\x01\x12\x1a\n\x12prefetch_watermark\x18\x04 \x01(\x01\"o\n\x08Resource\x12\x15\n\rresource_path\x18\x01 \x01(\t\x12\x44\n\x10hierarchical_drr\x18\x02 \x01(\x0b\x32(.Ydb.RateLimiter.HierarchicalDrrSettingsH\x00\x42\x06\n\x04type\"\x9f\x01\n\x15\x43reateResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12+\n\x08resource\x18\x03 \x01(\x0b\x32\x19.Ydb.RateLimiter.Resource\"F\n\x16\x43reateResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14\x43reateResourceResult\"\x9e\x01\n\x14\x41lterResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12+\n\x08resource\x18\x03 \x01(\x0b\x32\x19.Ydb.RateLimiter.Resource\"E\n\x15\x41lterResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13\x41lterResourceResult\"\x87\x01\n\x13\x44ropResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\"D\n\x14\x44ropResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x44ropResourceResult\"\x9b\x01\n\x14ListResourcesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\"E\n\x15ListResourcesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"-\n\x13ListResourcesResult\x12\x16\n\x0eresource_paths\x18\x01 \x03(\t\"\x8b\x01\n\x17\x44\x65scribeResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\"H\n\x18\x44\x65scribeResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x16\x44\x65scribeResourceResult\x12+\n\x08resource\x18\x01 \x01(\x0b\x32\x19.Ydb.RateLimiter.Resource\"\xb7\x01\n\x16\x41\x63quireResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\x12\x12\n\x08required\x18\x04 \x01(\x04H\x00\x12\x0e\n\x04used\x18\x05 \x01(\x04H\x00\x42\x07\n\x05units\"G\n\x17\x41\x63quireResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x17\n\x15\x41\x63quireResourceResultBo\n\x15tech.ydb.rate_limiterB\x11RateLimiterProtosP\x01Z>github.com/ydb-platform/ydb-go-genproto/protos/Ydb_RateLimiter\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])




_HIERARCHICALDRRSETTINGS = _descriptor.Descriptor(
  name='HierarchicalDrrSettings',
  full_name='Ydb.RateLimiter.HierarchicalDrrSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_units_per_second', full_name='Ydb.RateLimiter.HierarchicalDrrSettings.max_units_per_second', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_burst_size_coefficient', full_name='Ydb.RateLimiter.HierarchicalDrrSettings.max_burst_size_coefficient', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefetch_coefficient', full_name='Ydb.RateLimiter.HierarchicalDrrSettings.prefetch_coefficient', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefetch_watermark', full_name='Ydb.RateLimiter.HierarchicalDrrSettings.prefetch_watermark', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=228,
)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='Ydb.RateLimiter.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_path', full_name='Ydb.RateLimiter.Resource.resource_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hierarchical_drr', full_name='Ydb.RateLimiter.Resource.hierarchical_drr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='Ydb.RateLimiter.Resource.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=230,
  serialized_end=341,
)


_CREATERESOURCEREQUEST = _descriptor.Descriptor(
  name='CreateResourceRequest',
  full_name='Ydb.RateLimiter.CreateResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.RateLimiter.CreateResourceRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordination_node_path', full_name='Ydb.RateLimiter.CreateResourceRequest.coordination_node_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='Ydb.RateLimiter.CreateResourceRequest.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=503,
)


_CREATERESOURCERESPONSE = _descriptor.Descriptor(
  name='CreateResourceResponse',
  full_name='Ydb.RateLimiter.CreateResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.RateLimiter.CreateResourceResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=575,
)


_CREATERESOURCERESULT = _descriptor.Descriptor(
  name='CreateResourceResult',
  full_name='Ydb.RateLimiter.CreateResourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=599,
)


_ALTERRESOURCEREQUEST = _descriptor.Descriptor(
  name='AlterResourceRequest',
  full_name='Ydb.RateLimiter.AlterResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.RateLimiter.AlterResourceRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordination_node_path', full_name='Ydb.RateLimiter.AlterResourceRequest.coordination_node_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='Ydb.RateLimiter.AlterResourceRequest.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=760,
)


_ALTERRESOURCERESPONSE = _descriptor.Descriptor(
  name='AlterResourceResponse',
  full_name='Ydb.RateLimiter.AlterResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.RateLimiter.AlterResourceResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=831,
)


_ALTERRESOURCERESULT = _descriptor.Descriptor(
  name='AlterResourceResult',
  full_name='Ydb.RateLimiter.AlterResourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=854,
)


_DROPRESOURCEREQUEST = _descriptor.Descriptor(
  name='DropResourceRequest',
  full_name='Ydb.RateLimiter.DropResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.RateLimiter.DropResourceRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordination_node_path', full_name='Ydb.RateLimiter.DropResourceRequest.coordination_node_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_path', full_name='Ydb.RateLimiter.DropResourceRequest.resource_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=992,
)


_DROPRESOURCERESPONSE = _descriptor.Descriptor(
  name='DropResourceResponse',
  full_name='Ydb.RateLimiter.DropResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.RateLimiter.DropResourceResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1062,
)


_DROPRESOURCERESULT = _descriptor.Descriptor(
  name='DropResourceResult',
  full_name='Ydb.RateLimiter.DropResourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1084,
)


_LISTRESOURCESREQUEST = _descriptor.Descriptor(
  name='ListResourcesRequest',
  full_name='Ydb.RateLimiter.ListResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.RateLimiter.ListResourcesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordination_node_path', full_name='Ydb.RateLimiter.ListResourcesRequest.coordination_node_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_path', full_name='Ydb.RateLimiter.ListResourcesRequest.resource_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='Ydb.RateLimiter.ListResourcesRequest.recursive', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1242,
)


_LISTRESOURCESRESPONSE = _descriptor.Descriptor(
  name='ListResourcesResponse',
  full_name='Ydb.RateLimiter.ListResourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.RateLimiter.ListResourcesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1313,
)


_LISTRESOURCESRESULT = _descriptor.Descriptor(
  name='ListResourcesResult',
  full_name='Ydb.RateLimiter.ListResourcesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_paths', full_name='Ydb.RateLimiter.ListResourcesResult.resource_paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1360,
)


_DESCRIBERESOURCEREQUEST = _descriptor.Descriptor(
  name='DescribeResourceRequest',
  full_name='Ydb.RateLimiter.DescribeResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.RateLimiter.DescribeResourceRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordination_node_path', full_name='Ydb.RateLimiter.DescribeResourceRequest.coordination_node_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_path', full_name='Ydb.RateLimiter.DescribeResourceRequest.resource_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1363,
  serialized_end=1502,
)


_DESCRIBERESOURCERESPONSE = _descriptor.Descriptor(
  name='DescribeResourceResponse',
  full_name='Ydb.RateLimiter.DescribeResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.RateLimiter.DescribeResourceResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1576,
)


_DESCRIBERESOURCERESULT = _descriptor.Descriptor(
  name='DescribeResourceResult',
  full_name='Ydb.RateLimiter.DescribeResourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='Ydb.RateLimiter.DescribeResourceResult.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1647,
)


_ACQUIRERESOURCEREQUEST = _descriptor.Descriptor(
  name='AcquireResourceRequest',
  full_name='Ydb.RateLimiter.AcquireResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.RateLimiter.AcquireResourceRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordination_node_path', full_name='Ydb.RateLimiter.AcquireResourceRequest.coordination_node_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_path', full_name='Ydb.RateLimiter.AcquireResourceRequest.resource_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='Ydb.RateLimiter.AcquireResourceRequest.required', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used', full_name='Ydb.RateLimiter.AcquireResourceRequest.used', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='units', full_name='Ydb.RateLimiter.AcquireResourceRequest.units',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1650,
  serialized_end=1833,
)


_ACQUIRERESOURCERESPONSE = _descriptor.Descriptor(
  name='AcquireResourceResponse',
  full_name='Ydb.RateLimiter.AcquireResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.RateLimiter.AcquireResourceResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1835,
  serialized_end=1906,
)


_ACQUIRERESOURCERESULT = _descriptor.Descriptor(
  name='AcquireResourceResult',
  full_name='Ydb.RateLimiter.AcquireResourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1908,
  serialized_end=1931,
)

_RESOURCE.fields_by_name['hierarchical_drr'].message_type = _HIERARCHICALDRRSETTINGS
_RESOURCE.oneofs_by_name['type'].fields.append(
  _RESOURCE.fields_by_name['hierarchical_drr'])
_RESOURCE.fields_by_name['hierarchical_drr'].containing_oneof = _RESOURCE.oneofs_by_name['type']
_CREATERESOURCEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATERESOURCEREQUEST.fields_by_name['resource'].message_type = _RESOURCE
_CREATERESOURCERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ALTERRESOURCEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERRESOURCEREQUEST.fields_by_name['resource'].message_type = _RESOURCE
_ALTERRESOURCERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPRESOURCEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPRESOURCERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTRESOURCESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTRESOURCESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBERESOURCEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBERESOURCERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBERESOURCERESULT.fields_by_name['resource'].message_type = _RESOURCE
_ACQUIRERESOURCEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ACQUIRERESOURCEREQUEST.oneofs_by_name['units'].fields.append(
  _ACQUIRERESOURCEREQUEST.fields_by_name['required'])
_ACQUIRERESOURCEREQUEST.fields_by_name['required'].containing_oneof = _ACQUIRERESOURCEREQUEST.oneofs_by_name['units']
_ACQUIRERESOURCEREQUEST.oneofs_by_name['units'].fields.append(
  _ACQUIRERESOURCEREQUEST.fields_by_name['used'])
_ACQUIRERESOURCEREQUEST.fields_by_name['used'].containing_oneof = _ACQUIRERESOURCEREQUEST.oneofs_by_name['units']
_ACQUIRERESOURCERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['HierarchicalDrrSettings'] = _HIERARCHICALDRRSETTINGS
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['CreateResourceRequest'] = _CREATERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['CreateResourceResponse'] = _CREATERESOURCERESPONSE
DESCRIPTOR.message_types_by_name['CreateResourceResult'] = _CREATERESOURCERESULT
DESCRIPTOR.message_types_by_name['AlterResourceRequest'] = _ALTERRESOURCEREQUEST
DESCRIPTOR.message_types_by_name['AlterResourceResponse'] = _ALTERRESOURCERESPONSE
DESCRIPTOR.message_types_by_name['AlterResourceResult'] = _ALTERRESOURCERESULT
DESCRIPTOR.message_types_by_name['DropResourceRequest'] = _DROPRESOURCEREQUEST
DESCRIPTOR.message_types_by_name['DropResourceResponse'] = _DROPRESOURCERESPONSE
DESCRIPTOR.message_types_by_name['DropResourceResult'] = _DROPRESOURCERESULT
DESCRIPTOR.message_types_by_name['ListResourcesRequest'] = _LISTRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesResponse'] = _LISTRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name['ListResourcesResult'] = _LISTRESOURCESRESULT
DESCRIPTOR.message_types_by_name['DescribeResourceRequest'] = _DESCRIBERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['DescribeResourceResponse'] = _DESCRIBERESOURCERESPONSE
DESCRIPTOR.message_types_by_name['DescribeResourceResult'] = _DESCRIBERESOURCERESULT
DESCRIPTOR.message_types_by_name['AcquireResourceRequest'] = _ACQUIRERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['AcquireResourceResponse'] = _ACQUIRERESOURCERESPONSE
DESCRIPTOR.message_types_by_name['AcquireResourceResult'] = _ACQUIRERESOURCERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HierarchicalDrrSettings = _reflection.GeneratedProtocolMessageType('HierarchicalDrrSettings', (_message.Message,), {
  'DESCRIPTOR' : _HIERARCHICALDRRSETTINGS,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.HierarchicalDrrSettings)
  })
_sym_db.RegisterMessage(HierarchicalDrrSettings)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.Resource)
  })
_sym_db.RegisterMessage(Resource)

CreateResourceRequest = _reflection.GeneratedProtocolMessageType('CreateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEREQUEST,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.CreateResourceRequest)
  })
_sym_db.RegisterMessage(CreateResourceRequest)

CreateResourceResponse = _reflection.GeneratedProtocolMessageType('CreateResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCERESPONSE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.CreateResourceResponse)
  })
_sym_db.RegisterMessage(CreateResourceResponse)

CreateResourceResult = _reflection.GeneratedProtocolMessageType('CreateResourceResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCERESULT,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.CreateResourceResult)
  })
_sym_db.RegisterMessage(CreateResourceResult)

AlterResourceRequest = _reflection.GeneratedProtocolMessageType('AlterResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALTERRESOURCEREQUEST,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.AlterResourceRequest)
  })
_sym_db.RegisterMessage(AlterResourceRequest)

AlterResourceResponse = _reflection.GeneratedProtocolMessageType('AlterResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERRESOURCERESPONSE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.AlterResourceResponse)
  })
_sym_db.RegisterMessage(AlterResourceResponse)

AlterResourceResult = _reflection.GeneratedProtocolMessageType('AlterResourceResult', (_message.Message,), {
  'DESCRIPTOR' : _ALTERRESOURCERESULT,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.AlterResourceResult)
  })
_sym_db.RegisterMessage(AlterResourceResult)

DropResourceRequest = _reflection.GeneratedProtocolMessageType('DropResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPRESOURCEREQUEST,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.DropResourceRequest)
  })
_sym_db.RegisterMessage(DropResourceRequest)

DropResourceResponse = _reflection.GeneratedProtocolMessageType('DropResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPRESOURCERESPONSE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.DropResourceResponse)
  })
_sym_db.RegisterMessage(DropResourceResponse)

DropResourceResult = _reflection.GeneratedProtocolMessageType('DropResourceResult', (_message.Message,), {
  'DESCRIPTOR' : _DROPRESOURCERESULT,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.DropResourceResult)
  })
_sym_db.RegisterMessage(DropResourceResult)

ListResourcesRequest = _reflection.GeneratedProtocolMessageType('ListResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESREQUEST,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.ListResourcesRequest)
  })
_sym_db.RegisterMessage(ListResourcesRequest)

ListResourcesResponse = _reflection.GeneratedProtocolMessageType('ListResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESRESPONSE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.ListResourcesResponse)
  })
_sym_db.RegisterMessage(ListResourcesResponse)

ListResourcesResult = _reflection.GeneratedProtocolMessageType('ListResourcesResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESRESULT,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.ListResourcesResult)
  })
_sym_db.RegisterMessage(ListResourcesResult)

DescribeResourceRequest = _reflection.GeneratedProtocolMessageType('DescribeResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERESOURCEREQUEST,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.DescribeResourceRequest)
  })
_sym_db.RegisterMessage(DescribeResourceRequest)

DescribeResourceResponse = _reflection.GeneratedProtocolMessageType('DescribeResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERESOURCERESPONSE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.DescribeResourceResponse)
  })
_sym_db.RegisterMessage(DescribeResourceResponse)

DescribeResourceResult = _reflection.GeneratedProtocolMessageType('DescribeResourceResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERESOURCERESULT,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.DescribeResourceResult)
  })
_sym_db.RegisterMessage(DescribeResourceResult)

AcquireResourceRequest = _reflection.GeneratedProtocolMessageType('AcquireResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRERESOURCEREQUEST,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.AcquireResourceRequest)
  })
_sym_db.RegisterMessage(AcquireResourceRequest)

AcquireResourceResponse = _reflection.GeneratedProtocolMessageType('AcquireResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRERESOURCERESPONSE,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.AcquireResourceResponse)
  })
_sym_db.RegisterMessage(AcquireResourceResponse)

AcquireResourceResult = _reflection.GeneratedProtocolMessageType('AcquireResourceResult', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRERESOURCERESULT,
  '__module__' : 'protos.ydb_rate_limiter_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.RateLimiter.AcquireResourceResult)
  })
_sym_db.RegisterMessage(AcquireResourceResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
