# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_export.proto',
  package='Ydb.Export',
  syntax='proto3',
  serialized_options=b'\n\017tech.ydb.exportZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Export\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17protos/ydb_export.proto\x12\nYdb.Export\x1a#protos/annotations/validation.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb1\x01\n\x0e\x45xportProgress\"\x9e\x01\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x16\n\x12PROGRESS_PREPARING\x10\x01\x12\x1a\n\x16PROGRESS_TRANSFER_DATA\x10\x02\x12\x11\n\rPROGRESS_DONE\x10\x03\x12\x19\n\x15PROGRESS_CANCELLATION\x10\x04\x12\x16\n\x12PROGRESS_CANCELLED\x10\x05\"\xa0\x01\n\x12\x45xportItemProgress\x12\x13\n\x0bparts_total\x18\x01 \x01(\r\x12\x17\n\x0fparts_completed\x18\x02 \x01(\r\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x98\x02\n\x12\x45xportToYtSettings\x12\x12\n\x04host\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x13\n\x05token\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12:\n\x05items\x18\x04 \x03(\x0b\x32#.Ydb.Export.ExportToYtSettings.ItemB\x06\x9a\xe6*\x02(\x01\x12\x1c\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x06 \x01(\r\x12\x13\n\x0buse_type_v3\x18\x07 \x01(\x08\x1a\x41\n\x04Item\x12\x19\n\x0bsource_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x1e\n\x10\x64\x65stination_path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\"\x12\n\x10\x45xportToYtResult\"\xb5\x01\n\x12\x45xportToYtMetadata\x12\x30\n\x08settings\x18\x01 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Export.ExportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Export.ExportItemProgress\"\x86\x01\n\x11\x45xportToYtRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettingsB\x04\x90\xe6*\x01\"B\n\x12\x45xportToYtResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xbd\x05\n\x12\x45xportToS3Settings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x35\n\x06scheme\x18\x02 \x01(\x0e\x32%.Ydb.Export.ExportToS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12:\n\x05items\x18\x06 \x03(\x0b\x32#.Ydb.Export.ExportToS3Settings.ItemB\x06\x9a\xe6*\x02(\x01\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x08 \x01(\r\x12\x42\n\rstorage_class\x18\t \x01(\x0e\x32+.Ydb.Export.ExportToS3Settings.StorageClass\x12\x13\n\x0b\x63ompression\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x1a\x43\n\x04Item\x12\x19\n\x0bsource_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12 \n\x12\x64\x65stination_prefix\x18\x02 \x01(\tB\x04\x90\xe6*\x01\".\n\x06Scheme\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\"\xba\x01\n\x0cStorageClass\x12\x1d\n\x19STORAGE_CLASS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x16\n\x12REDUCED_REDUNDANCY\x10\x02\x12\x0f\n\x0bSTANDARD_IA\x10\x03\x12\x0e\n\nONEZONE_IA\x10\x04\x12\x17\n\x13INTELLIGENT_TIERING\x10\x05\x12\x0b\n\x07GLACIER\x10\x06\x12\x10\n\x0c\x44\x45\x45P_ARCHIVE\x10\x07\x12\x0c\n\x08OUTPOSTS\x10\x08\"\x12\n\x10\x45xportToS3Result\"\xb5\x01\n\x12\x45xportToS3Metadata\x12\x30\n\x08settings\x18\x01 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3Settings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Export.ExportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Export.ExportItemProgress\"\x86\x01\n\x11\x45xportToS3Request\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3SettingsB\x04\x90\xe6*\x01\"B\n\x12\x45xportToS3Response\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBO\n\x0ftech.ydb.exportZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Export\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_EXPORTPROGRESS_PROGRESS = _descriptor.EnumDescriptor(
  name='Progress',
  full_name='Ydb.Export.ExportProgress.Progress',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_PREPARING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_TRANSFER_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_DONE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_CANCELLATION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_CANCELLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=157,
  serialized_end=315,
)
_sym_db.RegisterEnumDescriptor(_EXPORTPROGRESS_PROGRESS)

_EXPORTTOS3SETTINGS_SCHEME = _descriptor.EnumDescriptor(
  name='Scheme',
  full_name='Ydb.Export.ExportToS3Settings.Scheme',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1639,
  serialized_end=1685,
)
_sym_db.RegisterEnumDescriptor(_EXPORTTOS3SETTINGS_SCHEME)

_EXPORTTOS3SETTINGS_STORAGECLASS = _descriptor.EnumDescriptor(
  name='StorageClass',
  full_name='Ydb.Export.ExportToS3Settings.StorageClass',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STORAGE_CLASS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STANDARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDUCED_REDUNDANCY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STANDARD_IA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONEZONE_IA', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTELLIGENT_TIERING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLACIER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEEP_ARCHIVE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPOSTS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1688,
  serialized_end=1874,
)
_sym_db.RegisterEnumDescriptor(_EXPORTTOS3SETTINGS_STORAGECLASS)


_EXPORTPROGRESS = _descriptor.Descriptor(
  name='ExportProgress',
  full_name='Ydb.Export.ExportProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPORTPROGRESS_PROGRESS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=315,
)


_EXPORTITEMPROGRESS = _descriptor.Descriptor(
  name='ExportItemProgress',
  full_name='Ydb.Export.ExportItemProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parts_total', full_name='Ydb.Export.ExportItemProgress.parts_total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts_completed', full_name='Ydb.Export.ExportItemProgress.parts_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='Ydb.Export.ExportItemProgress.start_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='Ydb.Export.ExportItemProgress.end_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=478,
)


_EXPORTTOYTSETTINGS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Export.ExportToYtSettings.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Export.ExportToYtSettings.Item.source_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Export.ExportToYtSettings.Item.destination_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=696,
  serialized_end=761,
)

_EXPORTTOYTSETTINGS = _descriptor.Descriptor(
  name='ExportToYtSettings',
  full_name='Ydb.Export.ExportToYtSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Export.ExportToYtSettings.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Export.ExportToYtSettings.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='Ydb.Export.ExportToYtSettings.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Export.ExportToYtSettings.items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Export.ExportToYtSettings.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='Ydb.Export.ExportToYtSettings.number_of_retries', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_type_v3', full_name='Ydb.Export.ExportToYtSettings.use_type_v3', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXPORTTOYTSETTINGS_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=761,
)


_EXPORTTOYTRESULT = _descriptor.Descriptor(
  name='ExportToYtResult',
  full_name='Ydb.Export.ExportToYtResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=763,
  serialized_end=781,
)


_EXPORTTOYTMETADATA = _descriptor.Descriptor(
  name='ExportToYtMetadata',
  full_name='Ydb.Export.ExportToYtMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Export.ExportToYtMetadata.settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='Ydb.Export.ExportToYtMetadata.progress', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items_progress', full_name='Ydb.Export.ExportToYtMetadata.items_progress', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=965,
)


_EXPORTTOYTREQUEST = _descriptor.Descriptor(
  name='ExportToYtRequest',
  full_name='Ydb.Export.ExportToYtRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Export.ExportToYtRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Export.ExportToYtRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1102,
)


_EXPORTTOYTRESPONSE = _descriptor.Descriptor(
  name='ExportToYtResponse',
  full_name='Ydb.Export.ExportToYtResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Export.ExportToYtResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1170,
)


_EXPORTTOS3SETTINGS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Export.ExportToS3Settings.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Export.ExportToS3Settings.Item.source_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_prefix', full_name='Ydb.Export.ExportToS3Settings.Item.destination_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1570,
  serialized_end=1637,
)

_EXPORTTOS3SETTINGS = _descriptor.Descriptor(
  name='ExportToS3Settings',
  full_name='Ydb.Export.ExportToS3Settings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='Ydb.Export.ExportToS3Settings.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='Ydb.Export.ExportToS3Settings.scheme', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='Ydb.Export.ExportToS3Settings.bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='Ydb.Export.ExportToS3Settings.access_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_key', full_name='Ydb.Export.ExportToS3Settings.secret_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Export.ExportToS3Settings.items', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Export.ExportToS3Settings.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='Ydb.Export.ExportToS3Settings.number_of_retries', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_class', full_name='Ydb.Export.ExportToS3Settings.storage_class', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='Ydb.Export.ExportToS3Settings.compression', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='Ydb.Export.ExportToS3Settings.region', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXPORTTOS3SETTINGS_ITEM, ],
  enum_types=[
    _EXPORTTOS3SETTINGS_SCHEME,
    _EXPORTTOS3SETTINGS_STORAGECLASS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1874,
)


_EXPORTTOS3RESULT = _descriptor.Descriptor(
  name='ExportToS3Result',
  full_name='Ydb.Export.ExportToS3Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=1894,
)


_EXPORTTOS3METADATA = _descriptor.Descriptor(
  name='ExportToS3Metadata',
  full_name='Ydb.Export.ExportToS3Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Export.ExportToS3Metadata.settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='Ydb.Export.ExportToS3Metadata.progress', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items_progress', full_name='Ydb.Export.ExportToS3Metadata.items_progress', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1897,
  serialized_end=2078,
)


_EXPORTTOS3REQUEST = _descriptor.Descriptor(
  name='ExportToS3Request',
  full_name='Ydb.Export.ExportToS3Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Export.ExportToS3Request.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Export.ExportToS3Request.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2081,
  serialized_end=2215,
)


_EXPORTTOS3RESPONSE = _descriptor.Descriptor(
  name='ExportToS3Response',
  full_name='Ydb.Export.ExportToS3Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Export.ExportToS3Response.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2283,
)

_EXPORTPROGRESS_PROGRESS.containing_type = _EXPORTPROGRESS
_EXPORTITEMPROGRESS.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTITEMPROGRESS.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTTOYTSETTINGS_ITEM.containing_type = _EXPORTTOYTSETTINGS
_EXPORTTOYTSETTINGS.fields_by_name['items'].message_type = _EXPORTTOYTSETTINGS_ITEM
_EXPORTTOYTMETADATA.fields_by_name['settings'].message_type = _EXPORTTOYTSETTINGS
_EXPORTTOYTMETADATA.fields_by_name['progress'].enum_type = _EXPORTPROGRESS_PROGRESS
_EXPORTTOYTMETADATA.fields_by_name['items_progress'].message_type = _EXPORTITEMPROGRESS
_EXPORTTOYTREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXPORTTOYTREQUEST.fields_by_name['settings'].message_type = _EXPORTTOYTSETTINGS
_EXPORTTOYTRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXPORTTOS3SETTINGS_ITEM.containing_type = _EXPORTTOS3SETTINGS
_EXPORTTOS3SETTINGS.fields_by_name['scheme'].enum_type = _EXPORTTOS3SETTINGS_SCHEME
_EXPORTTOS3SETTINGS.fields_by_name['items'].message_type = _EXPORTTOS3SETTINGS_ITEM
_EXPORTTOS3SETTINGS.fields_by_name['storage_class'].enum_type = _EXPORTTOS3SETTINGS_STORAGECLASS
_EXPORTTOS3SETTINGS_SCHEME.containing_type = _EXPORTTOS3SETTINGS
_EXPORTTOS3SETTINGS_STORAGECLASS.containing_type = _EXPORTTOS3SETTINGS
_EXPORTTOS3METADATA.fields_by_name['settings'].message_type = _EXPORTTOS3SETTINGS
_EXPORTTOS3METADATA.fields_by_name['progress'].enum_type = _EXPORTPROGRESS_PROGRESS
_EXPORTTOS3METADATA.fields_by_name['items_progress'].message_type = _EXPORTITEMPROGRESS
_EXPORTTOS3REQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXPORTTOS3REQUEST.fields_by_name['settings'].message_type = _EXPORTTOS3SETTINGS
_EXPORTTOS3RESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['ExportProgress'] = _EXPORTPROGRESS
DESCRIPTOR.message_types_by_name['ExportItemProgress'] = _EXPORTITEMPROGRESS
DESCRIPTOR.message_types_by_name['ExportToYtSettings'] = _EXPORTTOYTSETTINGS
DESCRIPTOR.message_types_by_name['ExportToYtResult'] = _EXPORTTOYTRESULT
DESCRIPTOR.message_types_by_name['ExportToYtMetadata'] = _EXPORTTOYTMETADATA
DESCRIPTOR.message_types_by_name['ExportToYtRequest'] = _EXPORTTOYTREQUEST
DESCRIPTOR.message_types_by_name['ExportToYtResponse'] = _EXPORTTOYTRESPONSE
DESCRIPTOR.message_types_by_name['ExportToS3Settings'] = _EXPORTTOS3SETTINGS
DESCRIPTOR.message_types_by_name['ExportToS3Result'] = _EXPORTTOS3RESULT
DESCRIPTOR.message_types_by_name['ExportToS3Metadata'] = _EXPORTTOS3METADATA
DESCRIPTOR.message_types_by_name['ExportToS3Request'] = _EXPORTTOS3REQUEST
DESCRIPTOR.message_types_by_name['ExportToS3Response'] = _EXPORTTOS3RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExportProgress = _reflection.GeneratedProtocolMessageType('ExportProgress', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTPROGRESS,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportProgress)
  })
_sym_db.RegisterMessage(ExportProgress)

ExportItemProgress = _reflection.GeneratedProtocolMessageType('ExportItemProgress', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTITEMPROGRESS,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportItemProgress)
  })
_sym_db.RegisterMessage(ExportItemProgress)

ExportToYtSettings = _reflection.GeneratedProtocolMessageType('ExportToYtSettings', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _EXPORTTOYTSETTINGS_ITEM,
    '__module__' : 'protos.ydb_export_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToYtSettings.Item)
    })
  ,
  'DESCRIPTOR' : _EXPORTTOYTSETTINGS,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToYtSettings)
  })
_sym_db.RegisterMessage(ExportToYtSettings)
_sym_db.RegisterMessage(ExportToYtSettings.Item)

ExportToYtResult = _reflection.GeneratedProtocolMessageType('ExportToYtResult', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOYTRESULT,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToYtResult)
  })
_sym_db.RegisterMessage(ExportToYtResult)

ExportToYtMetadata = _reflection.GeneratedProtocolMessageType('ExportToYtMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOYTMETADATA,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToYtMetadata)
  })
_sym_db.RegisterMessage(ExportToYtMetadata)

ExportToYtRequest = _reflection.GeneratedProtocolMessageType('ExportToYtRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOYTREQUEST,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToYtRequest)
  })
_sym_db.RegisterMessage(ExportToYtRequest)

ExportToYtResponse = _reflection.GeneratedProtocolMessageType('ExportToYtResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOYTRESPONSE,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToYtResponse)
  })
_sym_db.RegisterMessage(ExportToYtResponse)

ExportToS3Settings = _reflection.GeneratedProtocolMessageType('ExportToS3Settings', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _EXPORTTOS3SETTINGS_ITEM,
    '__module__' : 'protos.ydb_export_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToS3Settings.Item)
    })
  ,
  'DESCRIPTOR' : _EXPORTTOS3SETTINGS,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToS3Settings)
  })
_sym_db.RegisterMessage(ExportToS3Settings)
_sym_db.RegisterMessage(ExportToS3Settings.Item)

ExportToS3Result = _reflection.GeneratedProtocolMessageType('ExportToS3Result', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOS3RESULT,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToS3Result)
  })
_sym_db.RegisterMessage(ExportToS3Result)

ExportToS3Metadata = _reflection.GeneratedProtocolMessageType('ExportToS3Metadata', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOS3METADATA,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToS3Metadata)
  })
_sym_db.RegisterMessage(ExportToS3Metadata)

ExportToS3Request = _reflection.GeneratedProtocolMessageType('ExportToS3Request', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOS3REQUEST,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToS3Request)
  })
_sym_db.RegisterMessage(ExportToS3Request)

ExportToS3Response = _reflection.GeneratedProtocolMessageType('ExportToS3Response', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTOS3RESPONSE,
  '__module__' : 'protos.ydb_export_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Export.ExportToS3Response)
  })
_sym_db.RegisterMessage(ExportToS3Response)


DESCRIPTOR._options = None
_EXPORTTOYTSETTINGS_ITEM.fields_by_name['source_path']._options = None
_EXPORTTOYTSETTINGS_ITEM.fields_by_name['destination_path']._options = None
_EXPORTTOYTSETTINGS.fields_by_name['host']._options = None
_EXPORTTOYTSETTINGS.fields_by_name['token']._options = None
_EXPORTTOYTSETTINGS.fields_by_name['items']._options = None
_EXPORTTOYTSETTINGS.fields_by_name['description']._options = None
_EXPORTTOYTREQUEST.fields_by_name['settings']._options = None
_EXPORTTOS3SETTINGS_ITEM.fields_by_name['source_path']._options = None
_EXPORTTOS3SETTINGS_ITEM.fields_by_name['destination_prefix']._options = None
_EXPORTTOS3SETTINGS.fields_by_name['endpoint']._options = None
_EXPORTTOS3SETTINGS.fields_by_name['bucket']._options = None
_EXPORTTOS3SETTINGS.fields_by_name['access_key']._options = None
_EXPORTTOS3SETTINGS.fields_by_name['secret_key']._options = None
_EXPORTTOS3SETTINGS.fields_by_name['items']._options = None
_EXPORTTOS3SETTINGS.fields_by_name['description']._options = None
_EXPORTTOS3REQUEST.fields_by_name['settings']._options = None
# @@protoc_insertion_point(module_scope)
